@@ -1,8 +1,7 @@
 use crate::actor::*;
-use crate::HolochainP2pCell;
+use crate::HolochainP2pDna;
 use crate::*;
 use ::fixt::prelude::*;
-use holo_hash::fixt::AgentPubKeyFixturator;
 use holo_hash::fixt::DnaHashFixturator;
 use holo_hash::AgentPubKey;
 use holo_hash::DnaHash;
@@ -55,7 +54,6 @@ impl HolochainP2pHandler for StubNetwork {
     fn handle_publish(
         &mut self,
         dna_hash: DnaHash,
-        from_agent: AgentPubKey,
         request_validation_receipt: bool,
         countersigning_session: bool,
         dht_hash: holo_hash::AnyDhtHash,
@@ -73,7 +71,6 @@ impl HolochainP2pHandler for StubNetwork {
     fn handle_get(
         &mut self,
         dna_hash: DnaHash,
-        from_agent: AgentPubKey,
         dht_hash: holo_hash::AnyDhtHash,
         options: actor::GetOptions,
     ) -> HolochainP2pHandlerResult<Vec<WireOps>> {
@@ -82,7 +79,6 @@ impl HolochainP2pHandler for StubNetwork {
     fn handle_get_meta(
         &mut self,
         dna_hash: DnaHash,
-        from_agent: AgentPubKey,
         dht_hash: holo_hash::AnyDhtHash,
         options: actor::GetMetaOptions,
     ) -> HolochainP2pHandlerResult<Vec<MetadataSet>> {
@@ -91,7 +87,6 @@ impl HolochainP2pHandler for StubNetwork {
     fn handle_get_links(
         &mut self,
         dna_hash: DnaHash,
-        from_agent: AgentPubKey,
         link_key: WireLinkKey,
         options: actor::GetLinksOptions,
     ) -> HolochainP2pHandlerResult<Vec<WireLinkOps>> {
@@ -100,7 +95,6 @@ impl HolochainP2pHandler for StubNetwork {
     fn handle_get_agent_activity(
         &mut self,
         dna_hash: DnaHash,
-        from_agent: AgentPubKey,
         agent: AgentPubKey,
         query: ChainQueryFilter,
         options: actor::GetActivityOptions,
@@ -111,7 +105,6 @@ impl HolochainP2pHandler for StubNetwork {
         &mut self,
         dna_hash: DnaHash,
         to_agent: AgentPubKey,
-        from_agent: AgentPubKey,
         receipt: SerializedBytes,
     ) -> HolochainP2pHandlerResult<()> {
         Err("stub".into())
@@ -122,7 +115,6 @@ impl HolochainP2pHandler for StubNetwork {
     fn handle_authority_for_hash(
         &mut self,
         dna_hash: DnaHash,
-        agent: AgentPubKey,
         dht_hash: AnyDhtHash,
     ) -> HolochainP2pHandlerResult<bool> {
         Err("stub".into())
@@ -130,7 +122,6 @@ impl HolochainP2pHandler for StubNetwork {
     fn handle_countersigning_authority_response(
         &mut self,
         dna_hash: DnaHash,
-        from_agent: AgentPubKey,
         agents: Vec<AgentPubKey>,
         response: Vec<SignedHeader>,
     ) -> HolochainP2pHandlerResult<()> {
@@ -156,21 +147,20 @@ pub async fn stub_network() -> ghost_actor::GhostSender<HolochainP2p> {
 }
 
 fixturator!(
-    HolochainP2pCell;
+    HolochainP2pDna;
     curve Empty {
         tokio_helper::block_forever_on(async {
             let holochain_p2p = crate::test::stub_network().await;
-            holochain_p2p.to_cell(
+            holochain_p2p.to_dna(
                 DnaHashFixturator::new(Empty).next().unwrap(),
-                AgentPubKeyFixturator::new(Empty).next().unwrap(),
             )
         })
     };
     curve Unpredictable {
-        HolochainP2pCellFixturator::new(Empty).next().unwrap()
+        HolochainP2pDnaFixturator::new(Empty).next().unwrap()
     };
     curve Predictable {
-        HolochainP2pCellFixturator::new(Empty).next().unwrap()
+        HolochainP2pDnaFixturator::new(Empty).next().unwrap()
     };
 );
 
@@ -181,6 +171,7 @@ mod tests {
     use futures::future::FutureExt;
     use ghost_actor::GhostControlSender;
 
+    use crate::HolochainP2pSender;
     use holochain_zome_types::ValidationStatus;
     use kitsune_p2p::dependencies::kitsune_p2p_proxy::TlsConfig;
     use kitsune_p2p::KitsuneP2pConfig;
@@ -267,7 +258,7 @@ mod tests {
     async fn test_send_validation_receipt_workflow() {
         let (dna, a1, a2, _) = test_setup();
 
-        let (p2p, mut evt) = spawn_holochain_p2p(
+        let (p2p, mut evt): (HolochainP2pRef, _) = spawn_holochain_p2p(
             KitsuneP2pConfig::default(),
             TlsConfig::new_ephemeral().await.unwrap(),
         )
@@ -300,14 +291,9 @@ mod tests {
         p2p.join(dna.clone(), a1.clone()).await.unwrap();
         p2p.join(dna.clone(), a2.clone()).await.unwrap();
 
-        p2p.send_validation_receipt(
-            dna,
-            a2,
-            a1,
-            UnsafeBytes::from(b"receipt-test".to_vec()).into(),
-        )
-        .await
-        .unwrap();
+        p2p.send_validation_receipt(dna, a1, UnsafeBytes::from(b"receipt-test".to_vec()).into())
+            .await
+            .unwrap();
 
         p2p.ghost_actor_shutdown().await.unwrap();
         r_task.await.unwrap();
@@ -362,7 +348,7 @@ mod tests {
         // this will fail because we can't reach any remote nodes
         // but, it still published locally, so our test will work
         let _ = p2p
-            .publish(dna, a1, true, false, header_hash, vec![], Some(200))
+            .publish(dna, true, false, header_hash, vec![], Some(200))
             .await;
 
         assert_eq!(3, recv_count.load(std::sync::atomic::Ordering::SeqCst));
@@ -441,7 +427,7 @@ mod tests {
 
         tracing::info!("test - get");
         let res = p2p
-            .get(dna, a1, hash, actor::GetOptions::default())
+            .get(dna, hash, actor::GetOptions::default())
             .await
             .unwrap();
 
@@ -518,7 +504,7 @@ mod tests {
         };
 
         let res = p2p
-            .get_links(dna, a1, link_key, actor::GetLinksOptions::default())
+            .get_links(dna, link_key, actor::GetLinksOptions::default())
             .await
             .unwrap();
 
